@@ -9,7 +9,7 @@ Tk::CodeText - Programmer's Swiss army knife Text widget.
 use strict;
 use warnings;
 use vars qw($VERSION);
-$VERSION = '0.48';
+$VERSION = '0.49';
 
 use base qw(Tk::Derived Tk::Frame);
 
@@ -520,8 +520,7 @@ sub Populate {
 	$text->bind('<KeyPress>', [$self, 'OnKeyPress', Ev('K') ]);
 	#lazy events
 	my @levents = qw(
-		ButtonPress ButtonRelease-1 
-		ButtonRelease-2 B2-Motion 
+		ButtonPress B2-Motion 
 		B1-Motion MouseWheel
 	);
 	foreach my $levent (@levents) {
@@ -1486,3 +1485,4 @@ __END__
 
 
 
+
